==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionMenuActionDescriptionMetadata } from "./ToolActionMenuActionDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
var ToolActionIconMenuDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconMenuDescriptionMetadata, _super);
    function ToolActionIconMenuDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionIconMenuDescriptionMetadata.b = function (a) {
        if (ToolActionIconMenuDescriptionMetadata.a == null) {
            ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
        }
        if (a.g(ToolActionIconMenuDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionIconMenuDescriptionMetadata.a);
    };
    ToolActionIconMenuDescriptionMetadata.c = function (a) {
        ToolActionMenuActionDescriptionMetadata.c(a);
    };
    ToolActionIconMenuDescriptionMetadata.d = function (a) {
        ToolActionIconMenuDescriptionMetadata.b(a);
        a.u("ToolActionIconMenu", function () { return new ToolActionIconMenuDescription(); });
        a.t("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
    };
    ToolActionIconMenuDescriptionMetadata.$t = markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
}(Base));
export { ToolActionIconMenuDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionMenuBaseDescriptionMetadata } from "./ToolActionMenuBaseDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
var ToolActionIconMenuDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconMenuDescriptionMetadata, _super);
    function ToolActionIconMenuDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionIconMenuDescriptionMetadata.b = function (a) {
        if (ToolActionIconMenuDescriptionMetadata.a == null) {
            ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
        }
        if (a.j(ToolActionIconMenuDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionIconMenuDescriptionMetadata.a);
    };
    ToolActionIconMenuDescriptionMetadata.c = function (a) {
        ToolActionMenuBaseDescriptionMetadata.c(a);
    };
    ToolActionIconMenuDescriptionMetadata.d = function (a) {
        ToolActionIconMenuDescriptionMetadata.b(a);
        a.aa("ToolActionIconMenu", function () { return new ToolActionIconMenuDescription(); });
        a.z("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
    };
    ToolActionIconMenuDescriptionMetadata.$t = markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
}(Base));
export { ToolActionIconMenuDescriptionMetadata };
